@@ -1,4 +1,8 @@
 #Prebird
 #Coded by L. Adrián Hernández A.
 
-from prebird.prebird import spec, process, display, result
\ No newline at end of file
+from prebird.prebird import spec, process, display, result
+
+"""
+El modulo preBird
+"""
\ No newline at end of file
